==> vue-comps-modal-0.0.1.tgz: package/modal.js <==
module.exports = {
  mixins: [require("vue-mixins/getVue")],
  filters: {
    notPrevented: require("vue-filters/notPrevented"),
    prevent: require("vue-filters/prevent")
  },
  created: function() {
    return this.overlay = require("vue-overlay")(this.getVue());
  },
  props: {
    "opacity": {
      type: Number,
      "default": 0.5
    },
    "dismissable": {
      type: Boolean,
      "default": true
    },
    "isOpened": {
      type: Boolean,
      "default": false
    },
    "fadeIn": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        this.style.opacity = 1;
        return cb();
      }
    },
    "fadeOut": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        this.style.opacity = 0;
        return cb();
      }
    },
    "parent": {
      type: Object
    },
    "onClick": {
      type: Boolean,
      "default": true
    }
  },
  data: function() {
    return {
      opened: false,
      closeOverlay: null,
      removeParentClickListener: null,
      style: {
        opacity: 0,
        position: "fixed",
        left: 0,
        right: 0,
        zIndex: 1000
      }
    };
  },
  watch: {
    "parent": "setupParent",
    "isOpened": function(val) {
      if (val !== this.opened) {
        if (val) {
          return this.open();
        } else {
          return this.close();
        }
      }
    }
  },
  events: {
    close: function() {
      this.close();
      return true;
    }
  },
  methods: {
    doNothing: function() {},
    dismiss: function() {
      if (this.dismissable) {
        return this.close();
      }
    },
    show: function() {
      this.opened = true;
      this.isOpened = true;
      return this.$nextTick((function(_this) {
        return function() {
          _this.$emit("beforeOpen");
          return _this.fadeIn({
            el: _this.$el,
            cb: function() {
              return _this.$emit("opened");
            }
          });
        };
      })(this));
    },
    hide: function() {
      if (!this.opened) {
        return;
      }
      this.$emit("beforeClose");
      return this.fadeIn({
        el: this.$el,
        cb: (function(_this) {
          return function() {
            _this.opened = false;
            _this.isOpened = false;
            return _this.$emit("closed");
          };
        })(this)
      });
    },
    open: function() {
      var close, ref, zIndex;
      if (this.opened) {
        return;
      }
      ref = this.overlay.open({
        dismissable: this.dismissable,
        opacity: this.opacity,
        onClosed: (function(_this) {
          return function() {
            return _this.close();
          };
        })(this)
      }), zIndex = ref.zIndex, close = ref.close;
      this.style.zIndex = zIndex;
      this.closeOverlay = close;
      return this.show();
    },
    close: function() {
      if (typeof this.closeOverlay === "function") {
        this.closeOverlay();
      }
      this.closeOverlay = null;
      return this.hide();
    },
    onParentClick: function(e) {
      if (e.defaultPrevented) {
        return;
      }
      if (this.opened) {
        this.close();
      } else {
        this.open();
      }
      return e.preventDefault();
    },
    setupParent: function(parent) {
      if (parent == null) {
        parent = this.parent;
      }
      if (this.onClick) {
        if (typeof this.removeParentClickListener === "function") {
          this.removeParentClickListener();
        }
        parent.addEventListener("click", this.onParentClick);
        return this.removeParentClickListener = (function(_this) {
          return function() {
            return parent.removeEventListener("click", _this.onParentClick);
          };
        })(this);
      }
    }
  },
  attached: function() {
    if (this.parent == null) {
      return this.parent = this.$el.parentElement;
    } else {
      return this.setupParent();
    }
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div v-bind:style=style v-if=opened @keyup.esc=\"dismiss | notPrevented | prevent\" @click=\"doNothing | notPrevented | prevent\" class=vc-modal><slot>No content</slot></div>"

==> vue-comps-modal-0.1.0.tgz: package/modal.js <==
module.exports = {
  mixins: [require("vue-mixins/getVue"), require("vue-mixins/isOpened"), require("vue-mixins/parentListener")],
  filters: {
    notPrevented: require("vue-filters/notPrevented"),
    prevent: require("vue-filters/prevent")
  },
  created: function() {
    return this.overlay = require("vue-overlay")(this.getVue());
  },
  props: {
    "class": {
      type: String,
      "default": "modal"
    },
    "opacity": {
      type: Number,
      "default": 0.5
    },
    "notDissmissible": {
      type: Boolean,
      "default": false
    },
    "transitionIn": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        this.style.opacity = 1;
        return cb();
      }
    },
    "transitionOut": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        this.style.opacity = 0;
        return cb();
      }
    }
  },
  data: function() {
    return {
      classes: [this["class"]],
      closeOverlay: null,
      style: {
        opacity: 0,
        position: "fixed",
        left: 0,
        right: 0,
        zIndex: 1000,
        display: "block"
      }
    };
  },
  events: {
    close: function() {
      this.close();
      return true;
    }
  },
  methods: {
    doNothing: function() {},
    dismiss: function() {
      if (!this.notDissmissible) {
        return this.close();
      }
    },
    show: function() {
      this.setOpened();
      this.$appendTo(document.body);
      return this.$nextTick((function(_this) {
        return function() {
          _this.$emit("beforeOpen");
          return _this.transitionIn({
            el: _this.$els.modal,
            cb: function() {
              return _this.$emit("opened");
            }
          });
        };
      })(this));
    },
    hide: function() {
      if (!this.opened) {
        return;
      }
      this.$emit("beforeClose");
      return this.transitionOut({
        el: this.$els.modal,
        cb: (function(_this) {
          return function() {
            _this.setClosed();
            _this.$emit("closed");
            return _this.$remove();
          };
        })(this)
      });
    },
    open: function() {
      var close, ref, zIndex;
      if (this.opened) {
        return;
      }
      ref = this.overlay.open({
        dissmissible: !this.notDissmissible,
        opacity: this.opacity,
        onBeforeClose: (function(_this) {
          return function() {
            return _this.close();
          };
        })(this)
      }), zIndex = ref.zIndex, close = ref.close;
      this.style.zIndex = zIndex;
      this.closeOverlay = close;
      return this.show();
    },
    close: function() {
      this.hide();
      if (typeof this.closeOverlay === "function") {
        this.closeOverlay();
      }
      return this.closeOverlay = null;
    },
    onParentClick: function(e) {
      if (e.defaultPrevented) {
        return;
      }
      if (this.opened) {
        this.close();
      } else {
        this.open();
      }
      return e.preventDefault();
    },
    toggle: function() {
      if (this.opened) {
        return this.open();
      } else {
        return this.close();
      }
    }
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div v-el:modal=v-el:modal v-bind:class=classes v-bind:style=style v-if=opened @keyup.esc=\"dismiss | notPrevented | prevent\" @click=\"doNothing | notPrevented | prevent\"><slot>No content</slot></div>"
